/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the Apple Extended Keyboard II.
 * By John Knox <johnx@exlog.com> and Chris Jones, Baker Hughes
 * Inteq DEAP Support, Aberdeen.
 */

static const KeyCode mac_codes [] = {

  /* Row 0 */
  61,
  130, 128, 107, 126,
  104, 105, 106, 108,
  109, 117, 111, 119,
  113, 115, 121,

  /* Row 2 */
  143, 26, 27, 28, 29, 31, 30, 34, 36, 33, 37, 35, 32, 59,
  122, 123, 124,
  79, 89, 83, 75,

  /* Row 3 */
  56, 20, 21, 22, 23, 25, 24, 40, 42, 39, 43, 41, 38,
  44,
  125, 127, 129,
  97, 99, 100, 86,

  /* Row 4 */
  65, 8, 9, 10, 11, 13, 12, 46, 48, 45, 49, 47, 50,
  94, 95, 96, 77,

  /* Row 5 */
  64, 58, 14, 15, 16, 17, 19, 53, 54, 51, 55, 52, 64,
  134,
  91, 92, 93, 84,

  /* Row 6 */
  67, 0, 0, 57, 0, 0, 67,
  131, 133, 132,
  90, 73
};
